@@ -11,6 +11,7 @@ from pytest_cpp.catch2 import Catch2Facade
 from pytest_cpp.error import CppFailureRepr
 from pytest_cpp.error import CppTestFailure
 from pytest_cpp.google import GoogleTestFacade
+from pytest_cpp.helpers import make_cmdline
 
 
 def assert_outcomes(result, expected_outcomes):
@@ -91,6 +92,23 @@ def test_success(facade, name, test_id, exes):
     assert facade.run_test(exes.get(name), test_id)[0] is None
 
 
+def test_cmdline_builder_happy_flow():
+    arg_string = make_cmdline(["wine"], "gtest", ["--help"])
+    assert arg_string == ["wine", "gtest", "--help"]
+
+
+def test_cmdline_builder_with_empty_harness():
+    arg_string = make_cmdline(
+        list(), "boost_test", ["--output_format=XML", "--log_sink=dummy.log"]
+    )
+    assert arg_string == ["boost_test", "--output_format=XML", "--log_sink=dummy.log"]
+
+
+def test_cmdline_builder_with_empty_args():
+    arg_string = make_cmdline(["wine"], "gtest")
+    assert arg_string == ["wine", "gtest"]
+
+
 def test_google_failure(exes):
     facade = GoogleTestFacade()
     failures, _ = facade.run_test(exes.get("gtest"), "FooTest.test_failure")
